/** DaytimeClient.java provides a client for TCP's daytime service.
 *  Attribute: Constant DAYTIME_PORT
 *  Methods:   main(), getTimeFrom()
 */

import java.net.*;        // Socket, ...
import java.io.*;         // BufferedReader, ...


class DaytimeClient extends Object
{
//--- main() method ---
 public static void main(String [] args)
 {
  if (args.length != 1)
  {
    System.err.println("Usage: java DaytimeClient <remoteHost>");
    System.exit(1);
  }

  DaytimeClient myClient = new DaytimeClient();
  System.out.println( myClient.getTimeFrom(args[0]) );
 }

/** Get time from server
 * Receive: String remoteHost
 * Return:  String representing time and date obtained from remoteHost
 *           or execution terminates due to an exception
 */ 
 public String getTimeFrom(String remoteHost)
 {
  String timeOfDay = null;
  try
  {
   Socket mySocket = new Socket(remoteHost, DAYTIME_PORT);
   BufferedReader myReader = new BufferedReader( 
                              new InputStreamReader( 
                               mySocket.getInputStream() ));
   timeOfDay = myReader.readLine();
	myReader.close();
  }
  catch (Exception e) 
  {
    System.err.println(e);
  }

  return timeOfDay;
 }

//--- Attribute variable ---
 private int DAYTIME_PORT = 13;
}

